import java.util.Vector;
import java.util.StringTokenizer;
import java.io.*;
import java.awt.*;
import java.awt.image.*;

//created packages
import trees.OrderedTree;
import compare.Comparable;

class Record implements Comparable
	{
	/*
	This class generalizes the key values to be inserted into
	binary search trees and other data structures.
	*/

	private String value;

	public Record(String value)
		{
		this.value = value;
		}

	public int compareTo(Comparable other)
		{
		return ((this.value).compareTo(((Record) other).value));
		}

	public String toString()
		{
		return value;
		}
	}

class DirFailedException extends Exception
	{
	DirFailedException(String exception)
		{
		System.out.println("dir command failed with exception: " + exception);
		}
	}

public class DirCommandTest extends Frame
	{
	OrderedTree t0, t1;

	Dimension sizeTree;
	Image treeImage;
	Graphics treeImageGraphics;
	Dimension treeImageSize;

	int displayWidth = 800;
	int displayHeight = 800;
	int imageWidth = 0;
	int imageHeight = 0;

	public static void main(String[] arguments)
		{
		DirCommandTest f = new DirCommandTest(arguments);
		f.resize(800, 800);
		f.show();
		}

	public boolean handleEvent(Event event)
		{
		if (event.id == Event.WINDOW_DESTROY)
			System.exit(0);
		return super.handleEvent(event);
		}

	DirCommandTest(String[] arguments)
		{
		String dirArg = "";
		if (arguments.length > 0)
			dirArg = arguments[0];

		String[] dirOutput;
		try
			{
			dirOutput = dir(dirArg);
			}
		catch (DirFailedException exception)
			{
			System.out.println("dir command failed: " + exception);
			return;
			}

		String[][] tokens = new String[dirOutput.length][];
		for (int i = 0; i < tokens.length; i++)
			{
			tokens[i] = new String[dirOutput[i].length()];
			StringTokenizer t = new StringTokenizer(dirOutput[i], ":\\");
			int j = 0;
			while (t.hasMoreTokens())
				{
				tokens[i][j] = t.nextToken();
				j++;
				}
			}

		Record[][] elts = new Record[tokens.length][];
		for (int i = 0; i < tokens.length; i++)
			{
			int j = 0;
			while (tokens[i][j] != null)
				j++;
			elts[i] = new Record[j];
			for (int k = 0; k < j; k++)
				elts[i][k] = new Record(tokens[i][k]);
			}

		t1 = new OrderedTree();

Record[] root0 = new Record[1];
root0[0] = new Record("E");
t1.insert(root0);
Record[] root1 = new Record[2];
root1[0] = new Record("E");
root1[1] = new Record("myjava");
t1.insert(root1);
Record[] root2 = new Record[3];
root2[0] = new Record("E");
root2[1] = new Record("myjava");
root2[2] = new Record("systems_stuff");
t1.insert(root2);

		for (int i = 0; i < elts.length; i++)
{
System.out.println("inserting ");
for (int j = 0; j < elts[i].length; j++)
	System.out.print(elts[i][j] + " ");
System.out.println();
			t1.insert(elts[i]);
}

		//Dimension sizeTree = t1.treeSize();
		}

	public static String[] dir(String directory) throws DirFailedException
		{
		/*
		Execute a dir command and return its output as a string array.
		Throws DirFailedException if the command failed.
		*/

		try
			{
			//set up the command
			String[] commandArray = {"cmd.exe /c dir /f/s ", directory};

			//execute it
			Process child = Runtime.getRuntime().exec(commandArray);

			//get its output
			DataInputStream in = new DataInputStream(child.getInputStream());
			Vector commandOutput = new Vector();
			String line;
			while ((line = in.readLine()) != null)
				commandOutput.addElement(line);

			//did it fail?
			if (child.waitFor() != 0)
				throw new DirFailedException("" + child.exitValue());

			//okay, command succeeded, return its output
			String[] returnValue = new String[commandOutput.size()];
			commandOutput.copyInto(returnValue);
			return returnValue;
			}
		catch (DirFailedException e) { throw e; }
		catch (Exception e) { throw new DirFailedException(e.toString()); }
		}

	public boolean imageUpdate(Image image, int infoFlags,
								int x, int y, int width, int height)
		{
		//if image is complete, get its dimensions
		if ((infoFlags & ImageObserver.ALLBITS) != 0)
			{
			imageWidth = image.getWidth(null);
			imageHeight = image.getHeight(null);
			repaint();
			return false;
			}
		else
			return true;
		}

	public void update(Graphics g)
		{
		Dimension d = this.size();
		if ((treeImage == null) ||
			(d.width != treeImageSize.width) ||
			(d.height != treeImageSize.height))
			{
			if (treeImage != null) treeImageGraphics.dispose();
			treeImage = createImage(d.width, d.height);
			treeImageGraphics = treeImage.getGraphics();
			treeImageGraphics.setColor(this.getBackground());
			treeImageGraphics.fillRect(0, 0, d.width, d.height);
			treeImageSize = d;
			t1.display(treeImageGraphics);
			paint(g);
			}
		}

	public void paint(Graphics g)
		{
		g.translate(5, 27);		//needed for os/2
		g.drawImage(treeImage, 0, 0, 800, 400, this);
		}

	}

/*
		String[][] s = {
						{"a"},

						{"a", "b"},
						{"a", "c"},
						{"a", "d"},

						{"a", "b", "e"},
						{"a", "b", "f"},

						{"a", "c", "g"},

						{"a", "d", "w"},
						{"a", "d", "x"},
						{"a", "d", "y"},
						{"a", "d", "z"},

						{"a", "b", "f", "h"},
						};

		Record[][] foo = new Record[20][];
		for (int i = 0; i < s.length; i++)
			{
			foo[i] = new Record[s[i].length];
			for (int j = 0; j < s[i].length; j++)
				foo[i][j] = new Record(s[i][j]);
			}

		t0 = new OrderedTree();
		for (int i = 0; i < s.length; i++)
			t0.insert(foo[i]);

		Dimension sizeTree = t0.treeSize();
		}
*/

